export type LinkProps = {
    /**
     * Content to render within the element.
     */
    children: React.ReactNode;
    /**
     * A class property to attach to the element.
     *
     * @see {@link !Element.className}
     */
    className?: string | undefined;
    /**
     * Indicates whether or not the link references a URL outside of the Netlify app.
     *
     * @default true
     */
    external?: boolean | undefined;
    /**
     * Indicates whether or not the link references a URL inside of the Netlify app.
     *
     * @default false
     */
    internal?: boolean | undefined;
    /**
     * The URL that the `Link` points to.
     */
    href?: string | undefined;
};
/**
 * A component used to render URLs.
 *
 * In addition to applying styling your links, using this component ensures your URLs open in a new
 * window. For security reasons, the sandboxed iframe extensions run in restrict modifying the
 * current browsing context's URL; extensions can, however, open links in a new window. We recommend
 * using this component to ensure your links consistently work.
 *
 * @param props
 * @param ref
 */
export declare const Link: import('react').ForwardRefExoticComponent<LinkProps & import('react').RefAttributes<HTMLAnchorElement | HTMLButtonElement>>;
//# sourceMappingURL=Link.d.ts.map